summaryrefslogtreecommitdiff
path: root/include/user/incoming_dialog.h
diff options
context:
space:
mode:
authorReiko Asakura2021-02-26 18:53:20 -0500
committerReiko Asakura2021-02-26 18:53:20 -0500
commitba8bc9e83266a42a39c673b710a35c75001b0a6e (patch)
treefd933140b9997f79c56df56ae433ddfba9c1a931 /include/user/incoming_dialog.h
parentAdd SceGxmInternal NIDs (diff)
downloadvds-libraries-ba8bc9e83266a42a39c673b710a35c75001b0a6e.tar.gz
Changes to user/incoming_dialog.h
Diffstat (limited to 'include/user/incoming_dialog.h')
-rw-r--r--include/user/incoming_dialog.h44
1 files changed, 27 insertions, 17 deletions
diff --git a/include/user/incoming_dialog.h b/include/user/incoming_dialog.h
index 73f2025..45c55e9 100644
--- a/include/user/incoming_dialog.h
+++ b/include/user/incoming_dialog.h
@@ -17,30 +17,39 @@ extern "C" {
* Dialog status
*/
typedef enum SceIncomingDialogStatus {
- SCE_INCOMING_DIALOG_NOT_RUNNING,
- SCE_INCOMING_DIALOG_BUSY,
- SCE_INCOMING_DIALOG_RUNNING,
- SCE_INCOMING_DIALOG_ACCEPTED,
- SCE_INCOMING_DIALOG_REJECTED,
- SCE_INCOMING_DIALOG_CLOSED,
- SCE_INCOMING_DIALOG_TIMEOUT,
+ SCE_INCOMING_DIALOG_STATUS_NONE,
+ SCE_INCOMING_DIALOG_STATUS_BUSY,
+ SCE_INCOMING_DIALOG_STATUS_RUNNING,
+ SCE_INCOMING_DIALOG_STATUS_ACCEPTED,
+ SCE_INCOMING_DIALOG_STATUS_REJECTED,
+ SCE_INCOMING_DIALOG_STATUS_CLOSED,
+ SCE_INCOMING_DIALOG_STATUS_TIMEOUT,
} SceIncomingDialogStatus;
/**
* Errors
*/
-#define SCE_INCOMING_DIALOG_ERROR_INVALID_ARG ((int)0x80106202)
+#define SCE_INCOMING_DIALOG_ERROR_NOT_INITIALIZED -2146409983 /* 0x80106201 */
+#define SCE_INCOMING_DIALOG_ERROR_INVALID_ARGUMENT -2146409982 /* 0x80106202 */
typedef struct SceIncomingDialogParam {
SceInt32 sdkVersion;
- SceChar8 titleid[0x10]; // TitleId of the application to open when "accept" button has been pressed. Can be all zero.
- SceChar8 audioPath[0x80]; // Path to audio file that will be played during dialog, .mp3, .at9, m4a. Can be all zero.
- SceUInt32 dialogTimer; // Time to show dialog in seconds
- SceInt32 unk_BC; // Can be set to 0
- SceChar8 reserved1[0x3E];
- SceWChar16 buttonRightText[0x20]; // Text for "accept" button. Must be null-terminated.
- SceWChar16 buttonLeftText[0x20]; // Text for "reject" button. Must be null-terminated. If all zero, only "accept" button will be created.
- SceWChar16 dialogText[0x81]; // Text for dialog window, also shared with notification. Must be null-terminated.
+ SceChar8 titleId[0x10]; /* Title ID of the application to open when "accept" button has been pressed.
+ The icon of this application is shown in the dialog. Can be empty. */
+ SceChar8 audioPath[0x80]; /* Path to audio file that plays when the dialog is opened. File types can be
+ mp3, at9, m4a. Can be empty. */
+ SceUInt32 timeout; /* Time in seconds before the dialog closes automatically. */
+ SceChar8 unk1; /* Set to zero. */
+ SceWChar16 unk2[0x20]; /* Set to zero. */
+ SceWChar16 acceptText[0x20]; /* Text for "accept" button. */
+ SceWChar16 rejectText[0x20]; /* Text for "reject" button. If empty, this button will not be displayed. */
+ SceWChar16 dialogText[0x40]; /* Text for dialog window. When the dialog is opened, a notification with the
+ same text will be displayed. */
+ SceWChar16 notificationText[0x40]; /* Text for a notification that shows after the dialog is closed for any
+ reason. If empty, the notification will not be shown. */
+ SceChar8 appParam[]; /* String to pass to the application that is opened when the "accept" button
+ is pressed. Can be a string of length zero but must not have size zero.
+ The opened application can retrieve this with sceAppMgrGetAppParam. */
} SceIncomingDialogParam;
/**
@@ -51,7 +60,7 @@ SceInt32 sceIncomingDialogInit(int initType);
/**
* Open incoming dialog.
*/
-SceInt32 sceIncomingDialogOpen(SceIncomingDialogParam* dialogParam);
+SceInt32 sceIncomingDialogOpen(const SceIncomingDialogParam* dialogParam);
/**
* Returns current status of incoming dialog.
@@ -78,6 +87,7 @@ void sceIncomingDialogParamInit(SceIncomingDialogParam* dialogParam)
{
sceClibMemset(dialogParam, 0x0, sizeof(SceIncomingDialogParam));
dialogParam->sdkVersion = SCE_PSP2_SDK_VERSION;
+ dialogParam->appParam[0] = 0;
}
#ifdef __cplusplus